"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
require("../../../client/dist/internal/logger/index.cjs");
const intervalRetrier = require("../../../client/dist/internal/async/interval-retrier.cjs");
const api = require("../../../client/dist/scw/api.cjs");
const marshalling = require("../../../client/dist/helpers/marshalling.cjs");
require("../../../client/dist/vendor/base64/index.cjs");
const resourcePaginator = require("../../../client/dist/scw/fetch/resource-paginator.cjs");
const content_gen = require("./content.gen.cjs");
const marshalling_gen = require("./marshalling.gen.cjs");
const jsonContentHeaders = {
  "Content-Type": "application/json; charset=utf-8"
};
class API extends api.API {
  /**
   * Activate the Cockpit of a given Project specified by the Project ID.
   *
   * @param request - The request {@link ActivateCockpitRequest}
   * @returns A Promise of Cockpit
   */
  activateCockpit = (request = {}) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalActivateCockpitRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/cockpit/v1beta1/activate`
    },
    marshalling_gen.unmarshalCockpit
  );
  /**
   * Retrieve the Cockpit of a given Project specified by the Project ID.
   *
   * @param request - The request {@link GetCockpitRequest}
   * @returns A Promise of Cockpit
   */
  getCockpit = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1beta1/cockpit`,
      urlParams: marshalling.urlParams([
        "project_id",
        request.projectId ?? this.client.settings.defaultProjectId
      ])
    },
    marshalling_gen.unmarshalCockpit
  );
  /**
   * Waits for {@link Cockpit} to be in a final state.
   *
   * @param request - The request {@link GetCockpitRequest}
   * @param options - The waiting options
   * @returns A Promise of Cockpit
   */
  waitForCockpit = (request = {}, options) => intervalRetrier.waitForResource(
    options?.stop ?? ((res) => Promise.resolve(!content_gen.COCKPIT_TRANSIENT_STATUSES.includes(res.status))),
    this.getCockpit,
    request,
    options
  );
  /**
   * Retrieve metrics from your Cockpit specified by the ID of the Project the
   * Cockpit belongs to.
   *
   * @param request - The request {@link GetCockpitMetricsRequest}
   * @returns A Promise of CockpitMetrics
   */
  getCockpitMetrics = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1beta1/cockpit/metrics`,
      urlParams: marshalling.urlParams(
        ["end_date", request.endDate],
        ["metric_name", request.metricName],
        [
          "project_id",
          request.projectId ?? this.client.settings.defaultProjectId
        ],
        ["start_date", request.startDate]
      )
    },
    marshalling_gen.unmarshalCockpitMetrics
  );
  /**
   * Deactivate the Cockpit of a given Project specified by the Project ID.
   *
   * @param request - The request {@link DeactivateCockpitRequest}
   * @returns A Promise of Cockpit
   */
  deactivateCockpit = (request = {}) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalDeactivateCockpitRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/cockpit/v1beta1/deactivate`
    },
    marshalling_gen.unmarshalCockpit
  );
  /**
   * Create a data source for a given Project specified by the Project ID and
   * the data source type.
   *
   * @param request - The request {@link CreateDatasourceRequest}
   * @returns A Promise of Datasource
   */
  createDatasource = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalCreateDatasourceRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/cockpit/v1beta1/datasources`
    },
    marshalling_gen.unmarshalDatasource
  );
  /**
   * Delete a given data source specified by the data source ID.
   *
   * @param request - The request {@link DeleteDatasourceRequest}
   */
  deleteDatasource = (request) => this.client.fetch({
    method: "DELETE",
    path: `/cockpit/v1beta1/datasources/${marshalling.validatePathParam("datasourceId", request.datasourceId)}`
  });
  pageOfListDatasources = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1beta1/datasources`,
      urlParams: marshalling.urlParams(
        ["is_managed_by_scaleway", request.isManagedByScaleway],
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        [
          "project_id",
          request.projectId ?? this.client.settings.defaultProjectId
        ],
        ["types", request.types]
      )
    },
    marshalling_gen.unmarshalListDatasourcesResponse
  );
  /**
   * Get a list of data sources for the specified Project ID.
   *
   * @param request - The request {@link ListDatasourcesRequest}
   * @returns A Promise of ListDatasourcesResponse
   */
  listDatasources = (request = {}) => resourcePaginator.enrichForPagination("datasources", this.pageOfListDatasources, request);
  /**
   * Create a token in a given Project specified by the Project ID.
   *
   * @param request - The request {@link CreateTokenRequest}
   * @returns A Promise of Token
   */
  createToken = (request = {}) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalCreateTokenRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/cockpit/v1beta1/tokens`
    },
    marshalling_gen.unmarshalToken
  );
  pageOfListTokens = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1beta1/tokens`,
      urlParams: marshalling.urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        [
          "project_id",
          request.projectId ?? this.client.settings.defaultProjectId
        ]
      )
    },
    marshalling_gen.unmarshalListTokensResponse
  );
  /**
   * Get a list of tokens in a given Project specified by the Project ID.
   *
   * @param request - The request {@link ListTokensRequest}
   * @returns A Promise of ListTokensResponse
   */
  listTokens = (request = {}) => resourcePaginator.enrichForPagination("tokens", this.pageOfListTokens, request);
  /**
   * Retrieve a given token specified by the token ID.
   *
   * @param request - The request {@link GetTokenRequest}
   * @returns A Promise of Token
   */
  getToken = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1beta1/tokens/${marshalling.validatePathParam("tokenId", request.tokenId)}`
    },
    marshalling_gen.unmarshalToken
  );
  /**
   * Delete a given token specified by the token ID.
   *
   * @param request - The request {@link DeleteTokenRequest}
   */
  deleteToken = (request) => this.client.fetch({
    method: "DELETE",
    path: `/cockpit/v1beta1/tokens/${marshalling.validatePathParam("tokenId", request.tokenId)}`
  });
  /**
   * Create a contact point associated with the default receiver, to receive
   * alerts.
   *
   * @param request - The request {@link CreateContactPointRequest}
   * @returns A Promise of ContactPoint
   */
  createContactPoint = (request = {}) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalCreateContactPointRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/cockpit/v1beta1/contact-points`
    },
    marshalling_gen.unmarshalContactPoint
  );
  pageOfListContactPoints = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1beta1/contact-points`,
      urlParams: marshalling.urlParams(
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        [
          "project_id",
          request.projectId ?? this.client.settings.defaultProjectId
        ]
      )
    },
    marshalling_gen.unmarshalListContactPointsResponse
  );
  /**
   * Get a list of contact points created for a given Cockpit, specified by the
   * ID of the Project the Cockpit belongs to.
   *
   * @param request - The request {@link ListContactPointsRequest}
   * @returns A Promise of ListContactPointsResponse
   */
  listContactPoints = (request = {}) => resourcePaginator.enrichForPagination("contactPoints", this.pageOfListContactPoints, request);
  /**
   * Delete a contact point associated with the default receiver.
   *
   * @param request - The request {@link DeleteContactPointRequest}
   */
  deleteContactPoint = (request = {}) => this.client.fetch({
    body: JSON.stringify(
      marshalling_gen.marshalDeleteContactPointRequest(request, this.client.settings)
    ),
    headers: jsonContentHeaders,
    method: "POST",
    path: `/cockpit/v1beta1/delete-contact-point`
  });
  /**
   * Enable the sending of managed alerts for a given Cockpit, specified by the
   * ID of the Project the Cockpit belongs to.
   *
   * @param request - The request {@link EnableManagedAlertsRequest}
   */
  enableManagedAlerts = (request = {}) => this.client.fetch({
    body: JSON.stringify(
      marshalling_gen.marshalEnableManagedAlertsRequest(request, this.client.settings)
    ),
    headers: jsonContentHeaders,
    method: "POST",
    path: `/cockpit/v1beta1/enable-managed-alerts`
  });
  /**
   * Disable the sending of managed alerts for a given Cockpit, specified by the
   * ID of the Project the Cockpit belongs to.
   *
   * @param request - The request {@link DisableManagedAlertsRequest}
   */
  disableManagedAlerts = (request = {}) => this.client.fetch({
    body: JSON.stringify(
      marshalling_gen.marshalDisableManagedAlertsRequest(request, this.client.settings)
    ),
    headers: jsonContentHeaders,
    method: "POST",
    path: `/cockpit/v1beta1/disable-managed-alerts`
  });
  /**
   * Send a test alert to make sure your contact points get notified when an
   * actual alert is triggered.
   *
   * @param request - The request {@link TriggerTestAlertRequest}
   */
  triggerTestAlert = (request = {}) => this.client.fetch({
    body: JSON.stringify(
      marshalling_gen.marshalTriggerTestAlertRequest(request, this.client.settings)
    ),
    headers: jsonContentHeaders,
    method: "POST",
    path: `/cockpit/v1beta1/trigger-test-alert`
  });
  /**
   * Create a Grafana user for your Cockpit's Grafana. Make sure you save the
   * automatically-generated password and the Grafana user ID.
   *
   * @param request - The request {@link CreateGrafanaUserRequest}
   * @returns A Promise of GrafanaUser
   */
  createGrafanaUser = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalCreateGrafanaUserRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/cockpit/v1beta1/grafana-users`
    },
    marshalling_gen.unmarshalGrafanaUser
  );
  pageOfListGrafanaUsers = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1beta1/grafana-users`,
      urlParams: marshalling.urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        [
          "project_id",
          request.projectId ?? this.client.settings.defaultProjectId
        ]
      )
    },
    marshalling_gen.unmarshalListGrafanaUsersResponse
  );
  /**
   * Get a list of all Grafana users created in your Cockpit's Grafana.
   *
   * @param request - The request {@link ListGrafanaUsersRequest}
   * @returns A Promise of ListGrafanaUsersResponse
   */
  listGrafanaUsers = (request = {}) => resourcePaginator.enrichForPagination("grafanaUsers", this.pageOfListGrafanaUsers, request);
  /**
   * Delete a Grafana user from your Cockpit's Grafana, specified by the ID of
   * the Project the Cockpit belongs to, and the ID of the Grafana user.
   *
   * @param request - The request {@link DeleteGrafanaUserRequest}
   */
  deleteGrafanaUser = (request) => this.client.fetch({
    body: JSON.stringify(
      marshalling_gen.marshalDeleteGrafanaUserRequest(request, this.client.settings)
    ),
    headers: jsonContentHeaders,
    method: "POST",
    path: `/cockpit/v1beta1/grafana-users/${marshalling.validatePathParam("grafanaUserId", request.grafanaUserId)}/delete`
  });
  /**
   * Reset the password of a Grafana user, specified by the ID of the Project
   * the Cockpit belongs to, and the ID of the Grafana user.
   *
   * @param request - The request {@link ResetGrafanaUserPasswordRequest}
   * @returns A Promise of GrafanaUser
   */
  resetGrafanaUserPassword = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalResetGrafanaUserPasswordRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/cockpit/v1beta1/grafana-users/${marshalling.validatePathParam("grafanaUserId", request.grafanaUserId)}/reset-password`
    },
    marshalling_gen.unmarshalGrafanaUser
  );
  pageOfListPlans = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1beta1/plans`,
      urlParams: marshalling.urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ]
      )
    },
    marshalling_gen.unmarshalListPlansResponse
  );
  /**
   * Get a list of all pricing plans available.
   *
   * @param request - The request {@link ListPlansRequest}
   * @returns A Promise of ListPlansResponse
   */
  listPlans = (request = {}) => resourcePaginator.enrichForPagination("plans", this.pageOfListPlans, request);
  /**
   * Select your chosen pricing plan for your Cockpit, specifying the Cockpit's
   * Project ID and the pricing plan's ID in the request.
   *
   * @param request - The request {@link SelectPlanRequest}
   * @returns A Promise of SelectPlanResponse
   */
  selectPlan = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalSelectPlanRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/cockpit/v1beta1/select-plan`
    },
    marshalling_gen.unmarshalSelectPlanResponse
  );
  pageOfListGrafanaProductDashboards = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1beta1/grafana-product-dashboards`,
      urlParams: marshalling.urlParams(
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        [
          "project_id",
          request.projectId ?? this.client.settings.defaultProjectId
        ],
        ["tags", request.tags]
      )
    },
    marshalling_gen.unmarshalListGrafanaProductDashboardsResponse
  );
  /**
   * List product dashboards. Get a list of available product dashboards.
   *
   * @param request - The request {@link ListGrafanaProductDashboardsRequest}
   * @returns A Promise of ListGrafanaProductDashboardsResponse
   */
  listGrafanaProductDashboards = (request = {}) => resourcePaginator.enrichForPagination(
    "dashboards",
    this.pageOfListGrafanaProductDashboards,
    request
  );
  /**
   * Get a product dashboard. Get a product dashboard specified by the dashboard
   * ID.
   *
   * @param request - The request {@link GetGrafanaProductDashboardRequest}
   * @returns A Promise of GrafanaProductDashboard
   */
  getGrafanaProductDashboard = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/cockpit/v1beta1/grafana-product-dashboards/${marshalling.validatePathParam("dashboardName", request.dashboardName)}`,
      urlParams: marshalling.urlParams([
        "project_id",
        request.projectId ?? this.client.settings.defaultProjectId
      ])
    },
    marshalling_gen.unmarshalGrafanaProductDashboard
  );
}
exports.API = API;
