"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
require("../../../client/dist/internal/logger/index.cjs");
const intervalRetrier = require("../../../client/dist/internal/async/interval-retrier.cjs");
const api = require("../../../client/dist/scw/api.cjs");
const marshalling = require("../../../client/dist/helpers/marshalling.cjs");
require("../../../client/dist/vendor/base64/index.cjs");
const resourcePaginator = require("../../../client/dist/scw/fetch/resource-paginator.cjs");
const content_gen = require("./content.gen.cjs");
const marshalling_gen = require("./marshalling.gen.cjs");
const jsonContentHeaders = {
  "Content-Type": "application/json; charset=utf-8"
};
class API extends api.API {
  /** Lists the available regions of the API. */
  static LOCALITIES = [
    "fr-par",
    "nl-ams",
    "pl-waw"
  ];
  pageOfListDedicatedConnections = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/dedicated-connections`,
      urlParams: marshalling.urlParams(
        ["bandwidth_mbps", request.bandwidthMbps],
        ["name", request.name],
        ["order_by", request.orderBy],
        ["organization_id", request.organizationId],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["pop_id", request.popId],
        ["project_id", request.projectId],
        ["status", request.status],
        ["tags", request.tags]
      )
    },
    marshalling_gen.unmarshalListDedicatedConnectionsResponse
  );
  /**
   * List dedicated connections. For self-hosted users, list their dedicated
   * physical connections in a given region. By default, the connections
   * returned in the list are ordered by name in ascending order, though this
   * can be modified via the `order_by` field.
   *
   * @param request - The request {@link ListDedicatedConnectionsRequest}
   * @returns A Promise of ListDedicatedConnectionsResponse
   */
  listDedicatedConnections = (request = {}) => resourcePaginator.enrichForPagination(
    "connections",
    this.pageOfListDedicatedConnections,
    request
  );
  /**
   * Get a dedicated connection. For self-hosted users, get a dedicated physical
   * connection corresponding to the given ID. The response object includes
   * information such as the connection's name, status and total bandwidth.
   *
   * @param request - The request {@link GetDedicatedConnectionRequest}
   * @returns A Promise of DedicatedConnection
   */
  getDedicatedConnection = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/dedicated-connections/${marshalling.validatePathParam("connectionId", request.connectionId)}`
    },
    marshalling_gen.unmarshalDedicatedConnection
  );
  /**
   * Waits for {@link DedicatedConnection} to be in a final state.
   *
   * @param request - The request {@link GetDedicatedConnectionRequest}
   * @param options - The waiting options
   * @returns A Promise of DedicatedConnection
   */
  waitForDedicatedConnection = (request, options) => intervalRetrier.waitForResource(
    options?.stop ?? ((res) => Promise.resolve(
      !content_gen.DEDICATED_CONNECTION_TRANSIENT_STATUSES.includes(
        res.status
      )
    )),
    this.getDedicatedConnection,
    request,
    options
  );
  pageOfListPartners = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/partners`,
      urlParams: marshalling.urlParams(
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["pop_ids", request.popIds]
      )
    },
    marshalling_gen.unmarshalListPartnersResponse
  );
  /**
   * List available partners. List all available partners. By default, the
   * partners returned in the list are ordered by name in ascending order,
   * though this can be modified via the `order_by` field.
   *
   * @param request - The request {@link ListPartnersRequest}
   * @returns A Promise of ListPartnersResponse
   */
  listPartners = (request = {}) => resourcePaginator.enrichForPagination("partners", this.pageOfListPartners, request);
  /**
   * Get a partner. Get a partner for the given partner IP. The response object
   * includes information such as the partner's name, email address and portal
   * URL.
   *
   * @param request - The request {@link GetPartnerRequest}
   * @returns A Promise of Partner
   */
  getPartner = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/partners/${marshalling.validatePathParam("partnerId", request.partnerId)}`
    },
    marshalling_gen.unmarshalPartner
  );
  pageOfListPops = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/pops`,
      urlParams: marshalling.urlParams(
        ["dedicated_available", request.dedicatedAvailable],
        ["hosting_provider_name", request.hostingProviderName],
        ["link_bandwidth_mbps", request.linkBandwidthMbps],
        ["name", request.name],
        ["order_by", request.orderBy],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["partner_id", request.partnerId]
      )
    },
    marshalling_gen.unmarshalListPopsResponse
  );
  /**
   * List PoPs. List all available PoPs (locations) for a given region. By
   * default, the results are returned in ascending alphabetical order by name.
   *
   * @param request - The request {@link ListPopsRequest}
   * @returns A Promise of ListPopsResponse
   */
  listPops = (request = {}) => resourcePaginator.enrichForPagination("pops", this.pageOfListPops, request);
  /**
   * Get a PoP. Get a PoP for the given PoP ID. The response object includes the
   * PoP's name and information about its physical location.
   *
   * @param request - The request {@link GetPopRequest}
   * @returns A Promise of Pop
   */
  getPop = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/pops/${marshalling.validatePathParam("popId", request.popId)}`
    },
    marshalling_gen.unmarshalPop
  );
  pageOfListLinks = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links`,
      urlParams: marshalling.urlParams(
        ["bandwidth_mbps", request.bandwidthMbps],
        ["bgp_v4_status", request.bgpV4Status],
        ["bgp_v6_status", request.bgpV6Status],
        ["connection_id", request.connectionId],
        ["kind", request.kind],
        ["name", request.name],
        ["order_by", request.orderBy],
        ["organization_id", request.organizationId],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["pairing_key", request.pairingKey],
        ["partner_id", request.partnerId],
        ["pop_id", request.popId],
        ["project_id", request.projectId],
        ["routing_policy_id", request.routingPolicyId],
        ["status", request.status],
        ["tags", request.tags],
        ["vpc_id", request.vpcId]
      )
    },
    marshalling_gen.unmarshalListLinksResponse
  );
  /**
   * List links. List all your links (InterLink connections). A number of
   * filters are available, including Project ID, name, tags and status.
   *
   * @param request - The request {@link ListLinksRequest}
   * @returns A Promise of ListLinksResponse
   */
  listLinks = (request = {}) => resourcePaginator.enrichForPagination("links", this.pageOfListLinks, request);
  /**
   * Get a link. Get a link (InterLink session / logical InterLink resource) for
   * the given link ID. The response object includes information about the
   * link's various configuration details.
   *
   * @param request - The request {@link GetLinkRequest}
   * @returns A Promise of Link
   */
  getLink = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links/${marshalling.validatePathParam("linkId", request.linkId)}`
    },
    marshalling_gen.unmarshalLink
  );
  /**
   * Waits for {@link Link} to be in a final state.
   *
   * @param request - The request {@link GetLinkRequest}
   * @param options - The waiting options
   * @returns A Promise of Link
   */
  waitForLink = (request, options) => intervalRetrier.waitForResource(
    options?.stop ?? ((res) => Promise.resolve(
      !content_gen.LINK_TRANSIENT_STATUSES.includes(res.status)
    )),
    this.getLink,
    request,
    options
  );
  /**
   * Create a link. Create a link (InterLink session / logical InterLink
   * resource) in a given PoP, specifying its various configuration details.
   * Links can either be hosted (faciliated by partners' shared physical
   * connections) or self-hosted (for users who have purchased a dedicated
   * physical connection).
   *
   * @param request - The request {@link CreateLinkRequest}
   * @returns A Promise of Link
   */
  createLink = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalCreateLinkRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links`
    },
    marshalling_gen.unmarshalLink
  );
  /**
   * Update a link. Update an existing link, specified by its link ID. Only its
   * name and tags can be updated.
   *
   * @param request - The request {@link UpdateLinkRequest}
   * @returns A Promise of Link
   */
  updateLink = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalUpdateLinkRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links/${marshalling.validatePathParam("linkId", request.linkId)}`
    },
    marshalling_gen.unmarshalLink
  );
  /**
   * Delete a link. Delete an existing link, specified by its link ID. Note that
   * as well as deleting the link here on the Scaleway side, it is also
   * necessary to request deletion from the partner on their side. Only when
   * this action has been carried out on both sides will the resource be
   * completely deleted.
   *
   * @param request - The request {@link DeleteLinkRequest}
   * @returns A Promise of Link
   */
  deleteLink = (request) => this.client.fetch(
    {
      method: "DELETE",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links/${marshalling.validatePathParam("linkId", request.linkId)}`
    },
    marshalling_gen.unmarshalLink
  );
  /**
   * Attach a VPC. Attach a VPC to an existing link. This facilitates
   * communication between the resources in your Scaleway VPC, and your
   * on-premises infrastructure.
   *
   * @param request - The request {@link AttachVpcRequest}
   * @returns A Promise of Link
   */
  attachVpc = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalAttachVpcRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links/${marshalling.validatePathParam("linkId", request.linkId)}/attach-vpc`
    },
    marshalling_gen.unmarshalLink
  );
  /**
   * Detach a VPC. Detach a VPC from an existing link.
   *
   * @param request - The request {@link DetachVpcRequest}
   * @returns A Promise of Link
   */
  detachVpc = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links/${marshalling.validatePathParam("linkId", request.linkId)}/detach-vpc`
    },
    marshalling_gen.unmarshalLink
  );
  /**
   * Attach a routing policy. Attach a routing policy to an existing link. As
   * all routes across the link are blocked by default, you must attach a
   * routing policy to set IP prefix filters for allowed routes, facilitating
   * traffic flow.
   *
   * @param request - The request {@link AttachRoutingPolicyRequest}
   * @returns A Promise of Link
   */
  attachRoutingPolicy = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalAttachRoutingPolicyRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links/${marshalling.validatePathParam("linkId", request.linkId)}/attach-routing-policy`
    },
    marshalling_gen.unmarshalLink
  );
  /**
   * Detach a routing policy. Detach a routing policy from an existing link.
   * Without a routing policy, all routes across the link are blocked by
   * default.
   *
   * @param request - The request {@link DetachRoutingPolicyRequest}
   * @returns A Promise of Link
   */
  detachRoutingPolicy = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links/${marshalling.validatePathParam("linkId", request.linkId)}/detach-routing-policy`
    },
    marshalling_gen.unmarshalLink
  );
  /**
   * Enable route propagation. Enable all allowed prefixes (defined in a routing
   * policy) to be announced in the BGP session. This allows traffic to flow
   * between the attached VPC and the on-premises infrastructure along the
   * announced routes. Note that by default, even when route propagation is
   * enabled, all routes are blocked. It is essential to attach a routing policy
   * to define the ranges of routes to announce.
   *
   * @param request - The request {@link EnableRoutePropagationRequest}
   * @returns A Promise of Link
   */
  enableRoutePropagation = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links/${marshalling.validatePathParam("linkId", request.linkId)}/enable-route-propagation`
    },
    marshalling_gen.unmarshalLink
  );
  /**
   * Disable route propagation. Prevent any prefixes from being announced in the
   * BGP session. Traffic will not be able to flow over the InterLink until
   * route propagation is re-enabled.
   *
   * @param request - The request {@link DisableRoutePropagationRequest}
   * @returns A Promise of Link
   */
  disableRoutePropagation = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/links/${marshalling.validatePathParam("linkId", request.linkId)}/disable-route-propagation`
    },
    marshalling_gen.unmarshalLink
  );
  pageOfListRoutingPolicies = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/routing-policies`,
      urlParams: marshalling.urlParams(
        ["name", request.name],
        ["order_by", request.orderBy],
        ["organization_id", request.organizationId],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId],
        ["tags", request.tags]
      )
    },
    marshalling_gen.unmarshalListRoutingPoliciesResponse
  );
  /**
   * List routing policies. List all routing policies in a given region. A
   * routing policy can be attached to one or multiple links (InterLink
   * connections).
   *
   * @param request - The request {@link ListRoutingPoliciesRequest}
   * @returns A Promise of ListRoutingPoliciesResponse
   */
  listRoutingPolicies = (request = {}) => resourcePaginator.enrichForPagination(
    "routingPolicies",
    this.pageOfListRoutingPolicies,
    request
  );
  /**
   * Get routing policy. Get a routing policy for the given routing policy ID.
   * The response object gives information including the policy's name, tags and
   * prefix filters.
   *
   * @param request - The request {@link GetRoutingPolicyRequest}
   * @returns A Promise of RoutingPolicy
   */
  getRoutingPolicy = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/routing-policies/${marshalling.validatePathParam("routingPolicyId", request.routingPolicyId)}`
    },
    marshalling_gen.unmarshalRoutingPolicy
  );
  /**
   * Create a routing policy. Create a routing policy. Routing policies allow
   * you to set IP prefix filters to define the incoming route announcements to
   * accept from the peer, and the outgoing routes to announce to the peer.
   *
   * @param request - The request {@link CreateRoutingPolicyRequest}
   * @returns A Promise of RoutingPolicy
   */
  createRoutingPolicy = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalCreateRoutingPolicyRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/routing-policies`
    },
    marshalling_gen.unmarshalRoutingPolicy
  );
  /**
   * Update a routing policy. Update an existing routing policy, specified by
   * its routing policy ID. Its name, tags and incoming/outgoing prefix filters
   * can be updated.
   *
   * @param request - The request {@link UpdateRoutingPolicyRequest}
   * @returns A Promise of RoutingPolicy
   */
  updateRoutingPolicy = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalUpdateRoutingPolicyRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/routing-policies/${marshalling.validatePathParam("routingPolicyId", request.routingPolicyId)}`
    },
    marshalling_gen.unmarshalRoutingPolicy
  );
  /**
   * Delete a routing policy. Delete an existing routing policy, specified by
   * its routing policy ID.
   *
   * @param request - The request {@link DeleteRoutingPolicyRequest}
   */
  deleteRoutingPolicy = (request) => this.client.fetch({
    method: "DELETE",
    path: `/interlink/v1beta1/regions/${marshalling.validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/routing-policies/${marshalling.validatePathParam("routingPolicyId", request.routingPolicyId)}`
  });
}
exports.API = API;
