"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
require("../../../client/dist/internal/logger/index.cjs");
const intervalRetrier = require("../../../client/dist/internal/async/interval-retrier.cjs");
require("../../../client/dist/vendor/base64/index.cjs");
const api_gen = require("./api.gen.cjs");
const content_gen = require("./content.gen.cjs");
class LbV1UtilsAPI extends api_gen.API {
  /**
   * Waits for all private networks of a load balancer to be in a final state.
   *
   * @param request - The request {@link WaitForLbPrivateNetworksRequest}
   * @param options - The waiting options
   * @returns A Promise of ListLbPrivateNetworksResponse
   */
  waitForLbPrivateNetworks = (request, options) => intervalRetrier.tryAtIntervals(
    async () => {
      const value = await this.listLbPrivateNetworks({
        lbId: request.lbId,
        region: request.region
      }).all().then((list) => ({
        privateNetwork: list,
        totalCount: list.length
      }));
      return {
        done: value.privateNetwork.find(
          (elt) => content_gen.PRIVATE_NETWORK_TRANSIENT_STATUSES.includes(elt.status)
        ) === void 0,
        value
      };
    },
    intervalRetrier.createExponentialBackoffStrategy(
      options?.minDelay ?? 1,
      options?.maxDelay ?? 30
    ),
    options?.timeout
  );
  /**
   * Waits for all instances of a load balancer to be in a final state.
   *
   * @param request - The request {@link GetLbRequest}
   * @param options - The waiting options
   * @returns A Promise of Lb
   */
  waitForLbInstances = (request, options) => intervalRetrier.tryAtIntervals(
    async () => {
      const value = await this.getLb(request);
      return {
        done: !content_gen.LB_TRANSIENT_STATUSES.includes(value.status) && value.instances.find(
          (elt) => content_gen.INSTANCE_TRANSIENT_STATUSES.includes(elt.status)
        ) === void 0,
        value
      };
    },
    intervalRetrier.createExponentialBackoffStrategy(
      options?.minDelay ?? 1,
      options?.maxDelay ?? 30
    ),
    options?.timeout
  );
}
class LbZonedV1UtilsAPI extends api_gen.ZonedAPI {
  /**
   * Waits for all private networks of a (zoned) load balancer to be in a final
   * state.
   *
   * @param request - The request {@link ZonedWaitForLbPrivateNetworksRequest}
   * @param options - The waiting options
   * @returns A Promise of ListLbPrivateNetworksResponse
   */
  waitForLbPrivateNetworks = (request, options) => intervalRetrier.tryAtIntervals(
    async () => {
      const value = await this.listLbPrivateNetworks({
        lbId: request.lbId,
        zone: request.zone
      }).all().then((list) => ({
        privateNetwork: list,
        totalCount: list.length
      }));
      return {
        done: value.privateNetwork.find(
          (elt) => content_gen.PRIVATE_NETWORK_TRANSIENT_STATUSES.includes(elt.status)
        ) === void 0,
        value
      };
    },
    intervalRetrier.createExponentialBackoffStrategy(
      options?.minDelay ?? 1,
      options?.maxDelay ?? 30
    ),
    options?.timeout
  );
  /**
   * Waits for all instances of a (zoned) load balancer to be in a final state.
   *
   * @param request - The request {@link GetLbRequest}
   * @param options - The waiting options
   * @returns A Promise of Lb
   */
  waitForLbInstances = (request, options) => intervalRetrier.tryAtIntervals(
    async () => {
      const value = await this.getLb(request);
      return {
        done: !content_gen.LB_TRANSIENT_STATUSES.includes(value.status) && value.instances.find(
          (elt) => content_gen.INSTANCE_TRANSIENT_STATUSES.includes(elt.status)
        ) === void 0,
        value
      };
    },
    intervalRetrier.createExponentialBackoffStrategy(
      options?.minDelay ?? 1,
      options?.maxDelay ?? 30
    ),
    options?.timeout
  );
}
exports.LbV1UtilsAPI = LbV1UtilsAPI;
exports.LbZonedV1UtilsAPI = LbZonedV1UtilsAPI;
