"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
require("../../../client/dist/internal/logger/index.cjs");
const intervalRetrier = require("../../../client/dist/internal/async/interval-retrier.cjs");
const api = require("../../../client/dist/scw/api.cjs");
const marshalling = require("../../../client/dist/helpers/marshalling.cjs");
require("../../../client/dist/vendor/base64/index.cjs");
const resourcePaginator = require("../../../client/dist/scw/fetch/resource-paginator.cjs");
const content_gen = require("./content.gen.cjs");
const marshalling_gen = require("./marshalling.gen.cjs");
const jsonContentHeaders = {
  "Content-Type": "application/json; charset=utf-8"
};
class API extends api.API {
  /** Lists the available zones of the API. */
  static LOCALITIES = [
    "fr-par-1",
    "fr-par-2",
    "nl-ams-1",
    "nl-ams-2",
    "pl-waw-1",
    "pl-waw-2"
  ];
  /**
   * Create a Redis™ Database Instance. Create a new Redis™ Database Instance
   * (Redis™ cluster). You must set the `zone`, `project_id`, `version`,
   * `node_type`, `user_name` and `password` parameters. Optionally you can
   * define `acl_rules`, `endpoints`, `tls_enabled` and `cluster_settings`.
   *
   * @param request - The request {@link CreateClusterRequest}
   * @returns A Promise of Cluster
   */
  createCluster = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalCreateClusterRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/clusters`
    },
    marshalling_gen.unmarshalCluster
  );
  /**
   * Update a Redis™ Database Instance. Update the parameters of a Redis™
   * Database Instance (Redis™ cluster), including `name`, `tags`, `user_name`
   * and `password`.
   *
   * @param request - The request {@link UpdateClusterRequest}
   * @returns A Promise of Cluster
   */
  updateCluster = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalUpdateClusterRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/clusters/${marshalling.validatePathParam("clusterId", request.clusterId)}`
    },
    marshalling_gen.unmarshalCluster
  );
  /**
   * Get a Redis™ Database Instance. Retrieve information about a Redis™
   * Database Instance (Redis™ cluster). Specify the `cluster_id` and `region`
   * in your request to get information such as `id`, `status`, `version`,
   * `tls_enabled`, `cluster_settings`, `upgradable_versions` and `endpoints`
   * about your cluster in the response.
   *
   * @param request - The request {@link GetClusterRequest}
   * @returns A Promise of Cluster
   */
  getCluster = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/clusters/${marshalling.validatePathParam("clusterId", request.clusterId)}`
    },
    marshalling_gen.unmarshalCluster
  );
  /**
   * Waits for {@link Cluster} to be in a final state.
   *
   * @param request - The request {@link GetClusterRequest}
   * @param options - The waiting options
   * @returns A Promise of Cluster
   */
  waitForCluster = (request, options) => intervalRetrier.waitForResource(
    options?.stop ?? ((res) => Promise.resolve(
      !content_gen.CLUSTER_TRANSIENT_STATUSES.includes(res.status)
    )),
    this.getCluster,
    request,
    options
  );
  pageOfListClusters = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/clusters`,
      urlParams: marshalling.urlParams(
        ["name", request.name],
        ["order_by", request.orderBy],
        ["organization_id", request.organizationId],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId],
        ["tags", request.tags],
        ["version", request.version]
      )
    },
    marshalling_gen.unmarshalListClustersResponse
  );
  /**
   * List Redis™ Database Instances. List all Redis™ Database Instances (Redis™
   * cluster) in the specified zone. By default, the Database Instances returned
   * in the list are ordered by creation date in ascending order, though this
   * can be modified via the order_by field. You can define additional
   * parameters for your query, such as `tags`, `name`, `organization_id` and
   * `version`.
   *
   * @param request - The request {@link ListClustersRequest}
   * @returns A Promise of ListClustersResponse
   */
  listClusters = (request = {}) => resourcePaginator.enrichForPagination("clusters", this.pageOfListClusters, request);
  /**
   * Scale up a Redis™ Database Instance. Upgrade your Redis™ Database Instance,
   * either by upgrading to a bigger node type (vertical scaling) or by adding
   * more nodes to your Database Instance to increase your number of endpoints
   * and distribute cache (horizontal scaling, available for clusters only).
   * Note that scaling horizontally your Redis™ Database Instance will not renew
   * its TLS certificate. In order to refresh the TLS certificate, you must use
   * the Renew TLS certificate endpoint.
   *
   * @param request - The request {@link MigrateClusterRequest}
   * @returns A Promise of Cluster
   */
  migrateCluster = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalMigrateClusterRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/clusters/${marshalling.validatePathParam("clusterId", request.clusterId)}/migrate`
    },
    marshalling_gen.unmarshalCluster
  );
  /**
   * Delete a Redis™ Database Instance. Delete a Redis™ Database Instance
   * (Redis™ cluster), specified by the `region` and `cluster_id` parameters.
   * Deleting a Database Instance is permanent, and cannot be undone. Note that
   * upon deletion all your data will be lost.
   *
   * @param request - The request {@link DeleteClusterRequest}
   * @returns A Promise of Cluster
   */
  deleteCluster = (request) => this.client.fetch(
    {
      method: "DELETE",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/clusters/${marshalling.validatePathParam("clusterId", request.clusterId)}`
    },
    marshalling_gen.unmarshalCluster
  );
  /**
   * Get metrics of a Redis™ Database Instance. Retrieve the metrics of a Redis™
   * Database Instance (Redis™ cluster). You can define the period from which to
   * retrieve metrics by specifying the `start_date` and `end_date`.
   *
   * @param request - The request {@link GetClusterMetricsRequest}
   * @returns A Promise of ClusterMetricsResponse
   */
  getClusterMetrics = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/clusters/${marshalling.validatePathParam("clusterId", request.clusterId)}/metrics`,
      urlParams: marshalling.urlParams(
        ["end_at", request.endAt],
        ["metric_name", request.metricName],
        ["start_at", request.startAt]
      )
    },
    marshalling_gen.unmarshalClusterMetricsResponse
  );
  pageOfListNodeTypes = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/node-types`,
      urlParams: marshalling.urlParams(
        ["include_disabled_types", request.includeDisabledTypes],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ]
      )
    },
    marshalling_gen.unmarshalListNodeTypesResponse
  );
  /**
   * List available node types. List all available node types. By default, the
   * node types returned in the list are ordered by creation date in ascending
   * order, though this can be modified via the `order_by` field.
   *
   * @param request - The request {@link ListNodeTypesRequest}
   * @returns A Promise of ListNodeTypesResponse
   */
  listNodeTypes = (request) => resourcePaginator.enrichForPagination("nodeTypes", this.pageOfListNodeTypes, request);
  pageOfListClusterVersions = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/cluster-versions`,
      urlParams: marshalling.urlParams(
        ["include_beta", request.includeBeta],
        ["include_deprecated", request.includeDeprecated],
        ["include_disabled", request.includeDisabled],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["version", request.version]
      )
    },
    marshalling_gen.unmarshalListClusterVersionsResponse
  );
  /**
   * List available Redis™ versions. List the Redis™ database engine versions
   * available. You can define additional parameters for your query, such as
   * `include_disabled`, `include_beta`, `include_deprecated` and `version`.
   *
   * @param request - The request {@link ListClusterVersionsRequest}
   * @returns A Promise of ListClusterVersionsResponse
   */
  listClusterVersions = (request) => resourcePaginator.enrichForPagination("versions", this.pageOfListClusterVersions, request);
  /**
   * Get the TLS certificate of a cluster. Retrieve information about the TLS
   * certificate of a Redis™ Database Instance (Redis™ cluster). Details like
   * name and content are returned in the response.
   *
   * @param request - The request {@link GetClusterCertificateRequest}
   * @returns A Promise of Blob
   */
  getClusterCertificate = (request) => this.client.fetch({
    method: "GET",
    path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/clusters/${marshalling.validatePathParam("clusterId", request.clusterId)}/certificate`,
    urlParams: marshalling.urlParams(["dl", 1]),
    responseType: "blob"
  });
  /**
   * Renew the TLS certificate of a cluster. Renew a TLS certificate for a
   * Redis™ Database Instance (Redis™ cluster). Renewing a certificate means
   * that you will not be able to connect to your Database Instance using the
   * previous certificate. You will also need to download and update the new
   * certificate for all database clients.
   *
   * @param request - The request {@link RenewClusterCertificateRequest}
   * @returns A Promise of Cluster
   */
  renewClusterCertificate = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/clusters/${marshalling.validatePathParam("clusterId", request.clusterId)}/renew-certificate`
    },
    marshalling_gen.unmarshalCluster
  );
  /**
   * Add advanced settings. Add an advanced setting to a Redis™ Database
   * Instance (Redis™ cluster). You must set the `name` and the `value` of each
   * setting.
   *
   * @param request - The request {@link AddClusterSettingsRequest}
   * @returns A Promise of ClusterSettingsResponse
   */
  addClusterSettings = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalAddClusterSettingsRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/clusters/${marshalling.validatePathParam("clusterId", request.clusterId)}/settings`
    },
    marshalling_gen.unmarshalClusterSettingsResponse
  );
  /**
   * Delete advanced setting. Delete an advanced setting in a Redis™ Database
   * Instance (Redis™ cluster). You must specify the names of the settings you
   * want to delete in the request body.
   *
   * @param request - The request {@link DeleteClusterSettingRequest}
   * @returns A Promise of Cluster
   */
  deleteClusterSetting = (request) => this.client.fetch(
    {
      method: "DELETE",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/clusters/${marshalling.validatePathParam("clusterId", request.clusterId)}/settings/${marshalling.validatePathParam("settingName", request.settingName)}`
    },
    marshalling_gen.unmarshalCluster
  );
  /**
   * Set advanced settings. Update an advanced setting for a Redis™ Database
   * Instance (Redis™ cluster). Settings added upon database engine
   * initalization can only be defined once, and cannot, therefore, be updated.
   *
   * @param request - The request {@link SetClusterSettingsRequest}
   * @returns A Promise of ClusterSettingsResponse
   */
  setClusterSettings = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalSetClusterSettingsRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PUT",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/clusters/${marshalling.validatePathParam("clusterId", request.clusterId)}/settings`
    },
    marshalling_gen.unmarshalClusterSettingsResponse
  );
  /**
   * Set ACL rules for a cluster. Replace all the ACL rules of a Redis™ Database
   * Instance (Redis™ cluster).
   *
   * @param request - The request {@link SetAclRulesRequest}
   * @returns A Promise of SetAclRulesResponse
   */
  setAclRules = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalSetAclRulesRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PUT",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/clusters/${marshalling.validatePathParam("clusterId", request.clusterId)}/acls`
    },
    marshalling_gen.unmarshalSetAclRulesResponse
  );
  /**
   * Add ACL rules for a cluster. Add an additional ACL rule to a Redis™
   * Database Instance (Redis™ cluster).
   *
   * @param request - The request {@link AddAclRulesRequest}
   * @returns A Promise of AddAclRulesResponse
   */
  addAclRules = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalAddAclRulesRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/clusters/${marshalling.validatePathParam("clusterId", request.clusterId)}/acls`
    },
    marshalling_gen.unmarshalAddAclRulesResponse
  );
  /**
   * Delete an ACL rule for a cluster. Delete an ACL rule of a Redis™ Database
   * Instance (Redis™ cluster). You must specify the `acl_id` of the rule you
   * want to delete in your request.
   *
   * @param request - The request {@link DeleteAclRuleRequest}
   * @returns A Promise of Cluster
   */
  deleteAclRule = (request) => this.client.fetch(
    {
      method: "DELETE",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/acls/${marshalling.validatePathParam("aclId", request.aclId)}`
    },
    marshalling_gen.unmarshalCluster
  );
  /**
   * Get an ACL rule. Retrieve information about an ACL rule of a Redis™
   * Database Instance (Redis™ cluster). You must specify the `acl_id` of the
   * rule in your request.
   *
   * @param request - The request {@link GetAclRuleRequest}
   * @returns A Promise of ACLRule
   */
  getAclRule = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/acls/${marshalling.validatePathParam("aclId", request.aclId)}`
    },
    marshalling_gen.unmarshalACLRule
  );
  /**
   * Set endpoints for a cluster. Update an endpoint for a Redis™ Database
   * Instance (Redis™ cluster). You must specify the `cluster_id` and the
   * `endpoints` parameters in your request.
   *
   * @param request - The request {@link SetEndpointsRequest}
   * @returns A Promise of SetEndpointsResponse
   */
  setEndpoints = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalSetEndpointsRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PUT",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/clusters/${marshalling.validatePathParam("clusterId", request.clusterId)}/endpoints`
    },
    marshalling_gen.unmarshalSetEndpointsResponse
  );
  /**
   * Add endpoints for a cluster. Add a new endpoint for a Redis™ Database
   * Instance (Redis™ cluster). You can add `private_network` or
   * `public_network` specifications to the body of the request.
   *
   * @param request - The request {@link AddEndpointsRequest}
   * @returns A Promise of AddEndpointsResponse
   */
  addEndpoints = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalAddEndpointsRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/clusters/${marshalling.validatePathParam("clusterId", request.clusterId)}/endpoints`
    },
    marshalling_gen.unmarshalAddEndpointsResponse
  );
  /**
   * Delete an endpoint for a cluster. Delete the endpoint of a Redis™ Database
   * Instance (Redis™ cluster). You must specify the `region` and `endpoint_id`
   * parameters of the endpoint you want to delete. Note that might need to
   * update any environment configurations that point to the deleted endpoint.
   *
   * @param request - The request {@link DeleteEndpointRequest}
   * @returns A Promise of Cluster
   */
  deleteEndpoint = (request) => this.client.fetch(
    {
      method: "DELETE",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/endpoints/${marshalling.validatePathParam("endpointId", request.endpointId)}`
    },
    marshalling_gen.unmarshalCluster
  );
  /**
   * Get an endpoint. Retrieve information about a Redis™ Database Instance
   * (Redis™ cluster) endpoint. Full details about the endpoint, like `ips`,
   * `port`, `private_network` and `public_network` specifications are returned
   * in the response.
   *
   * @param request - The request {@link GetEndpointRequest}
   * @returns A Promise of Endpoint
   */
  getEndpoint = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/endpoints/${marshalling.validatePathParam("endpointId", request.endpointId)}`
    },
    marshalling_gen.unmarshalEndpoint
  );
  /**
   * Update an endpoint. Update information about a Redis™ Database Instance
   * (Redis™ cluster) endpoint. Full details about the endpoint, like `ips`,
   * `port`, `private_network` and `public_network` specifications are returned
   * in the response.
   *
   * @param request - The request {@link UpdateEndpointRequest}
   * @returns A Promise of Endpoint
   */
  updateEndpoint = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalling_gen.marshalUpdateEndpointRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/redis/v1/zones/${marshalling.validatePathParam("zone", request.zone ?? this.client.settings.defaultZone)}/endpoints/${marshalling.validatePathParam("endpointId", request.endpointId)}`
    },
    marshalling_gen.unmarshalEndpoint
  );
}
exports.API = API;
