import "../../../client/dist/internal/logger/index.js";
import { waitForResource } from "../../../client/dist/internal/async/interval-retrier.js";
import { API as API$1 } from "../../../client/dist/scw/api.js";
import { validatePathParam, urlParams } from "../../../client/dist/helpers/marshalling.js";
import "../../../client/dist/vendor/base64/index.js";
import { enrichForPagination } from "../../../client/dist/scw/fetch/resource-paginator.js";
import { DATABASE_TRANSIENT_STATUSES } from "./content.gen.js";
import { marshalCreateDatabaseRequest, unmarshalDatabase, unmarshalListDatabasesResponse, marshalUpdateDatabaseRequest, marshalRestoreDatabaseFromBackupRequest, unmarshalDatabaseBackup, unmarshalListDatabaseBackupsResponse } from "./marshalling.gen.js";
const jsonContentHeaders = {
  "Content-Type": "application/json; charset=utf-8"
};
class API extends API$1 {
  /** Lists the available regions of the API. */
  static LOCALITIES = ["fr-par"];
  /**
   * Create a new Serverless SQL Database. You must provide the following
   * parameters: `organization_id`, `project_id`, `name`, `cpu_min`, `cpu_max`.
   * You can also provide `from_backup_id` to create a database from a backup.
   *
   * @param request - The request {@link CreateDatabaseRequest}
   * @returns A Promise of Database
   */
  createDatabase = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalCreateDatabaseRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/serverless-sqldb/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/databases`
    },
    unmarshalDatabase
  );
  /**
   * Get a database information. Retrieve information about your Serverless SQL
   * Database. You must provide the `database_id` parameter.
   *
   * @param request - The request {@link GetDatabaseRequest}
   * @returns A Promise of Database
   */
  getDatabase = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/serverless-sqldb/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/databases/${validatePathParam("databaseId", request.databaseId)}`
    },
    unmarshalDatabase
  );
  /**
   * Waits for {@link Database} to be in a final state.
   *
   * @param request - The request {@link GetDatabaseRequest}
   * @param options - The waiting options
   * @returns A Promise of Database
   */
  waitForDatabase = (request, options) => waitForResource(
    options?.stop ?? ((res) => Promise.resolve(
      !DATABASE_TRANSIENT_STATUSES.includes(res.status)
    )),
    this.getDatabase,
    request,
    options
  );
  /**
   * Delete a database. Deletes a database. You must provide the `database_id`
   * parameter. All data stored in the database will be permanently deleted.
   *
   * @param request - The request {@link DeleteDatabaseRequest}
   * @returns A Promise of Database
   */
  deleteDatabase = (request) => this.client.fetch(
    {
      method: "DELETE",
      path: `/serverless-sqldb/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/databases/${validatePathParam("databaseId", request.databaseId)}`
    },
    unmarshalDatabase
  );
  pageOfListDatabases = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/serverless-sqldb/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/databases`,
      urlParams: urlParams(
        ["name", request.name],
        ["order_by", request.orderBy],
        ["organization_id", request.organizationId],
        ["page", request.page],
        ["page_size", request.pageSize],
        [
          "project_id",
          request.projectId ?? this.client.settings.defaultProjectId
        ]
      )
    },
    unmarshalListDatabasesResponse
  );
  /**
   * List your Serverless SQL Databases. List all Serverless SQL Databases for a
   * given Scaleway Organization or Scaleway Project. By default, the databases
   * returned in the list are ordered by creation date in ascending order,
   * though this can be modified via the order_by field. For the `name`
   * parameter, the value you include will be checked against the whole name
   * string to see if it includes the string you put in the parameter.
   *
   * @param request - The request {@link ListDatabasesRequest}
   * @returns A Promise of ListDatabasesResponse
   */
  listDatabases = (request = {}) => enrichForPagination("databases", this.pageOfListDatabases, request);
  /**
   * Update database information. Update CPU limits of your Serverless SQL
   * Database. You must provide the `database_id` parameter.
   *
   * @param request - The request {@link UpdateDatabaseRequest}
   * @returns A Promise of Database
   */
  updateDatabase = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalUpdateDatabaseRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/serverless-sqldb/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/databases/${validatePathParam("databaseId", request.databaseId)}`
    },
    unmarshalDatabase
  );
  /**
   * Restore a database from a backup. Restore a database from a backup. You
   * must provide the `backup_id` parameter.
   *
   * @param request - The request {@link RestoreDatabaseFromBackupRequest}
   * @returns A Promise of Database
   */
  restoreDatabaseFromBackup = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalRestoreDatabaseFromBackupRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/serverless-sqldb/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/databases/${validatePathParam("databaseId", request.databaseId)}/restore`
    },
    unmarshalDatabase
  );
  /**
   * Get a database backup information. Retrieve information about your
   * Serverless SQL Database backup. You must provide the `backup_id`
   * parameter.
   *
   * @param request - The request {@link GetDatabaseBackupRequest}
   * @returns A Promise of DatabaseBackup
   */
  getDatabaseBackup = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/serverless-sqldb/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/backups/${validatePathParam("backupId", request.backupId)}`
    },
    unmarshalDatabaseBackup
  );
  pageOfListDatabaseBackups = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/serverless-sqldb/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/backups`,
      urlParams: urlParams(
        ["database_id", request.databaseId],
        ["order_by", request.orderBy],
        ["organization_id", request.organizationId],
        ["page", request.page],
        ["page_size", request.pageSize],
        ["project_id", request.projectId]
      )
    },
    unmarshalListDatabaseBackupsResponse
  );
  /**
   * List your Serverless SQL Database backups. List all Serverless SQL Database
   * backups for a given Scaleway Project or Database. By default, the backups
   * returned in the list are ordered by creation date in descending order,
   * though this can be modified via the order_by field.
   *
   * @param request - The request {@link ListDatabaseBackupsRequest}
   * @returns A Promise of ListDatabaseBackupsResponse
   */
  listDatabaseBackups = (request) => enrichForPagination("backups", this.pageOfListDatabaseBackups, request);
  /**
   * Export a database backup. Export a database backup providing a download
   * link once the export process is completed. You must provide the `backup_id`
   * parameter.
   *
   * @param request - The request {@link ExportDatabaseBackupRequest}
   * @returns A Promise of DatabaseBackup
   */
  exportDatabaseBackup = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/serverless-sqldb/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/backups/${validatePathParam("backupId", request.backupId)}/export`
    },
    unmarshalDatabaseBackup
  );
}
export {
  API
};
