import "../../../client/dist/internal/logger/index.js";
import { waitForResource } from "../../../client/dist/internal/async/interval-retrier.js";
import { API as API$1 } from "../../../client/dist/scw/api.js";
import { urlParams, validatePathParam } from "../../../client/dist/helpers/marshalling.js";
import "../../../client/dist/vendor/base64/index.js";
import { enrichForPagination } from "../../../client/dist/scw/fetch/resource-paginator.js";
import { HUMAN_TRANSIENT_STATUSES } from "./content.gen.js";
import { marshalRegisterRequest, unmarshalRegisterResponse, unmarshalListHumansResponse, unmarshalHuman, marshalCreateHumanRequest, marshalUpdateHumanRequest } from "./marshalling.gen.js";
const jsonContentHeaders = {
  "Content-Type": "application/json; charset=utf-8"
};
class API extends API$1 {
  /**
   * Register a user. Register a human and return a access-key and a secret-key
   * that must be used in all other commands.
   *
   * Hint: you can use other test commands by setting the SCW_SECRET_KEY env
   * variable.
   *
   * @param request - The request {@link RegisterRequest}
   * @returns A Promise of RegisterResponse
   */
  register = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalRegisterRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/test/v1/register`
    },
    unmarshalRegisterResponse
  );
  pageOfListHumans = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/test/v1/humans`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["organization_id", request.organizationId],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId]
      )
    },
    unmarshalListHumansResponse
  );
  /**
   * List all your humans.
   *
   * @param request - The request {@link ListHumansRequest}
   * @returns A Promise of ListHumansResponse
   */
  listHumans = (request = {}) => enrichForPagination("humans", this.pageOfListHumans, request);
  /**
   * Get human details. Get the human details associated with the given id.
   *
   * @param request - The request {@link GetHumanRequest}
   * @returns A Promise of Human
   */
  getHuman = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/test/v1/humans/${validatePathParam("humanId", request.humanId)}`
    },
    unmarshalHuman
  );
  /**
   * Waits for {@link Human} to be in a final state.
   *
   * @param request - The request {@link GetHumanRequest}
   * @param options - The waiting options
   * @returns A Promise of Human
   */
  waitForHuman = (request, options) => waitForResource(
    options?.stop ?? ((res) => Promise.resolve(!HUMAN_TRANSIENT_STATUSES.includes(res.status))),
    this.getHuman,
    request,
    options
  );
  /**
   * Create a new human.
   *
   * @param request - The request {@link CreateHumanRequest}
   * @returns A Promise of Human
   */
  createHuman = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalCreateHumanRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/test/v1/humans`
    },
    unmarshalHuman
  );
  /**
   * Update an existing human. Update the human associated with the given id.
   *
   * @param request - The request {@link UpdateHumanRequest}
   * @returns A Promise of Human
   */
  updateHuman = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalUpdateHumanRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/test/v1/humans/${validatePathParam("humanId", request.humanId)}`
    },
    unmarshalHuman
  );
  /**
   * Delete an existing human. Delete the human associated with the given id.
   *
   * @param request - The request {@link DeleteHumanRequest}
   * @returns A Promise of Human
   */
  deleteHuman = (request) => this.client.fetch(
    {
      method: "DELETE",
      path: `/test/v1/humans/${validatePathParam("humanId", request.humanId)}`
    },
    unmarshalHuman
  );
  /**
   * Start a 1h running for the given human. Start a one hour running for the
   * given human.
   *
   * @param request - The request {@link RunHumanRequest}
   * @returns A Promise of Human
   */
  runHuman = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/test/v1/humans/${validatePathParam("humanId", request.humanId)}/run`
    },
    unmarshalHuman
  );
  /**
   * Make a human smoke.
   *
   * @deprecated
   * @param request - The request {@link SmokeHumanRequest}
   * @returns A Promise of Human
   */
  smokeHuman = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/test/v1/humans/${validatePathParam("humanId", request.humanId)}/smoke`
    },
    unmarshalHuman
  );
}
export {
  API
};
